@@ -577,7 +577,7 @@ ggally_dot_and_box_no_facet <- function(data, mapping, ..., boxPlot = TRUE) {
   if (horizontal) {
     p <- p +
       scale_x_discrete(
-        breaks = rev(levels(eval_data_col(data, mapping$x)))
+        limits = rev(levels(eval_data_col(data, mapping$x)))
       ) +
       coord_flip()
   }
@@ -844,7 +844,7 @@ ggally_barDiag <- function(data, mapping, ..., rescale = FALSE){
 }
 
 
-#' GGplot Text
+#' Text Plot
 #'
 #' Plot text for a plot.
 #'
