@@ -127,18 +127,6 @@ fix_column_values <- function(
     }
   }
 
-  colnamesUsed <- colnamesData[columns]
-  nameIsOnlyNumber <- ! str_detect(colnamesUsed, "[^0-9]")
-  if (any(nameIsOnlyNumber)) {
-    badColumns <- colnamesUsed[nameIsOnlyNumber]
-    names(badColumns) <- paste("column =", columns[nameIsOnlyNumber])
-    warning(paste(
-      "Data column name is numeric.  Desired behavior may not be as expected.\n\n",
-      "c(", paste("'", names(badColumns), "' = '", badColumns, "'", collapse = "", sep = ""), ")",
-      sep = ""
-    ))
-  }
-
   columns
 }
 
@@ -518,7 +506,7 @@ ggduo <- function(
 
     sectionAes <- add_and_overwrite_aes(
       add_and_overwrite_aes(
-        aes_string(x = xColName, y = yColName),
+        aes_(x = as.name(xColName), y = as.name(yColName)),
         mapping
       ),
       types$mapping
@@ -819,7 +807,7 @@ ggpairs <- function(
 
     sectionAes <- add_and_overwrite_aes(
       add_and_overwrite_aes(
-        aes_string(x = xColName, y = yColName),
+        aes_(x = as.name(xColName), y = as.name(yColName)),
         mapping
       ),
       types$mapping
@@ -867,7 +855,7 @@ ggpairs <- function(
 #'
 #' @keywords internal
 #' @author Barret Schloerke \email{schloerke@@gmail.com}
-#' @return aes_string output
+#' @return aes_ output
 #' @import ggplot2
 #' @rdname add_and_overwrite_aes
 #' @examples
